package com.aucma.report.mapper;

import java.util.List;
import com.aucma.report.domain.RecordException;

/**
 * 成品下线异常记录Mapper接口
 * 
 * @author Yinq
 * @date 2024-04-01
 */
public interface RecordExceptionMapper 
{
    /**
     * 查询成品下线异常记录
     * 
     * @param objId 成品下线异常记录主键
     * @return 成品下线异常记录
     */
    public RecordException selectRecordExceptionByObjId(Long objId);

    /**
     * 查询成品下线异常记录列表
     * 
     * @param recordException 成品下线异常记录
     * @return 成品下线异常记录集合
     */
    public List<RecordException> selectRecordExceptionList(RecordException recordException);

    /**
     * 新增成品下线异常记录
     * 
     * @param recordException 成品下线异常记录
     * @return 结果
     */
    public int insertRecordException(RecordException recordException);

    /**
     * 修改成品下线异常记录
     * 
     * @param recordException 成品下线异常记录
     * @return 结果
     */
    public int updateRecordException(RecordException recordException);

    /**
     * 删除成品下线异常记录
     * 
     * @param objId 成品下线异常记录主键
     * @return 结果
     */
    public int deleteRecordExceptionByObjId(Long objId);

    /**
     * 批量删除成品下线异常记录
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordExceptionByObjIds(Long[] objIds);
}
