package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.RecordException;
import com.aucma.report.service.IRecordExceptionService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 成品下线异常记录Controller
 *
 * @author Yinq
 * @date 2024-04-01
 */
@RestController
@RequestMapping("/report/recordException")
public class RecordExceptionController extends BaseController {
    @Autowired
    private IRecordExceptionService recordExceptionService;

    /**
     * 查询成品下线异常记录列表
     */
    @PreAuthorize("@ss.hasPermi('report:recordException:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordException recordException) {
        startPage();
        List<RecordException> list = recordExceptionService.selectRecordExceptionList(recordException);
        return getDataTable(list);
    }

    /**
     * 导出成品下线异常记录列表
     */
    @PreAuthorize("@ss.hasPermi('report:recordException:export')")
    @Log(title = "成品下线异常记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordException recordException) {
        List<RecordException> list = recordExceptionService.selectRecordExceptionList(recordException);
        ExcelUtil<RecordException> util = new ExcelUtil<RecordException>(RecordException.class);
        util.exportExcel(response, list, "成品下线异常记录数据");
    }

    /**
     * 获取成品下线异常记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:recordException:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(recordExceptionService.selectRecordExceptionByObjId(objId));
    }

    /**
     * 新增成品下线异常记录
     */
    @PreAuthorize("@ss.hasPermi('report:recordException:add')")
    @Log(title = "成品下线异常记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordException recordException) {
        return toAjax(recordExceptionService.insertRecordException(recordException));
    }

    /**
     * 修改成品下线异常记录
     */
    @PreAuthorize("@ss.hasPermi('report:recordException:edit')")
    @Log(title = "成品下线异常记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordException recordException) {
        return toAjax(recordExceptionService.updateRecordException(recordException));
    }

    /**
     * 删除成品下线异常记录
     */
    @PreAuthorize("@ss.hasPermi('report:recordException:remove')")
    @Log(title = "成品下线异常记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordExceptionService.deleteRecordExceptionByObjIds(objIds));
    }
}
